@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Tickit::Widget::LinearBox );
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use List::Util qw( sum max );
 
@@ -23,8 +23,6 @@ C<Tickit::Widget::HBox> - distribute child widgets in a horizontal row
  use Tickit::Widget::HBox;
  use Tickit::Widget::Static;
  
- my $tickit = Tickit->new;
- 
  my $hbox = Tickit::Widget::HBox->new;
 
  foreach my $position (qw( left centre right )) {
@@ -38,9 +36,7 @@ C<Tickit::Widget::HBox> - distribute child widgets in a horizontal row
     );
  }
  
- $tickit->set_root_widget( $hbox );
- 
- $tickit->run;
+ Tickit->new( root => $hbox )->run;
 
 =head1 DESCRIPTION
 
