@@ -571,17 +571,7 @@ int tickit_term_setctl_int(TickitTerm *tt, TickitTermCtl ctl, int value)
   return (*tt->driver->vtable->setctl_int)(tt->driver, ctl, value);
 }
 
-void tickit_term_set_mode_altscreen(TickitTerm *tt, int on)
+int tickit_term_setctl_str(TickitTerm *tt, TickitTermCtl ctl, const char *value)
 {
-  tickit_term_setctl_int(tt, TICKIT_TERMCTL_ALTSCREEN, on);
-}
-
-void tickit_term_set_mode_cursorvis(TickitTerm *tt, int on)
-{
-  tickit_term_setctl_int(tt, TICKIT_TERMCTL_CURSORVIS, on);
-}
-
-void tickit_term_set_mode_mouse(TickitTerm *tt, int on)
-{
-  tickit_term_setctl_int(tt, TICKIT_TERMCTL_MOUSE, on);
+  return (*tt->driver->vtable->setctl_str)(tt->driver, ctl, value);
 }
